OC.L10N.register(
    "core",
    {
    "Please select a file." : "Ver venleg og vel ei fil.",
    "File is too big" : "Fila er for stor",
    "Invalid file provided" : "Ugyldig fil",
    "No image or file provided" : "Inga bilete eller fil gjeve",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "An error occurred. Please contact your admin." : "Det oppstod ein feil. Ver venleg og kontakt systemadministrator.",
    "No temporary profile picture available, try again" : "Inga midlertidig profilbilete tilgjengeleg, prøv igjen",
    "No crop data provided" : "Ingen beskjeringsdata gjeve",
    "No valid crop data provided" : "Fekk inga beskjeringsdata",
    "Crop is not square" : "Beskjeringa er ikkje kvadratisk",
    "Couldn't reset password because the token is invalid" : "Kunne ikkje nullstilla passordet sidan tokenet er ugyldig",
    "Couldn't reset password because the token is expired" : "Kunne ikkje nullstilla passordet sidan tokenet er utløpt",
    "Couldn't send reset email. Please make sure your username is correct." : "Klarte ikkje senda e-post. Ver venleg og sjekk at brukarnamnet er korrekt.",
    "%s password reset" : "%s passordnullstilling",
    "Couldn't send mail to following users: %s " : "Kunne ikkje snede e-post til følgande brukarar: %s ",
    "Turned on maintenance mode" : "Skrudde på vedlikehaldsmodus",
    "Turned off maintenance mode" : "Skrudde av vedlikehaldsmodus",
    "Updated database" : "Database oppdatert",
    "Updated \"%s\" to %s" : "Oppdaterte «%s» til %s",
    "Starting code integrity check" : "Startar kodeintegritetstest",
    "Finished code integrity check" : "Fullførte kodeintegritetstest",
    "%s (3rdparty)" : "%s (tredjeparts)",
    "%s (incompatible)" : "%s (inkompatibel)",
    "Already up to date" : "Allereie oppdatert",
    "Sunday" : "Søndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sun." : "Søn.",
    "Mon." : "Mån.",
    "Tue." : "Tys.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lau.",
    "Su" : "Su",
    "Mo" : "Må",
    "Tu" : "Ty",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "La",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar,",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Settings" : "Innstillingar",
    "Saving..." : "Lagrar …",
    "Dismiss" : "Forkast",
    "seconds ago" : "sekund sidan",
    "I know what I'm doing" : "Eg veit kva eg gjer",
    "No" : "Nei",
    "Yes" : "Ja",
    "Choose" : "Vel",
    "Error loading file picker template: {error}" : "Klarte ikkje å lasta filplukkarmal: {error}",
    "Ok" : "Greitt",
    "Error loading message template: {error}" : "Klarte ikkje å lasta meldingsmal: {error}",
    "read-only" : "skriveverna",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonfliktar"],
    "One file conflict" : "Éin filkonflikt",
    "New Files" : "Nye filer",
    "Already existing files" : "Eksisterande filer",
    "Which files do you want to keep?" : "Kva filer vil du spara?",
    "If you select both versions, the copied file will have a number added to its name." : "Viss du vel begge utgåvene, vil den kopierte fila få eit tal lagt til namnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Gå vidare",
    "(all selected)" : "(alle valte)",
    "({count} selected)" : "({count} valte)",
    "Error loading file exists template" : "Klarte ikkje å lasta fil-finst-mal",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "OK passord",
    "Strong password" : "Bra passord",
    "Shared" : "Delt",
    "Error" : "Feil",
    "Error while sharing" : "Feil ved deling",
    "Error while unsharing" : "Feil ved udeling",
    "Error setting expiration date" : "Klarte ikkje setja utløpsdato",
    "Set expiration date" : "Set utløpsdato",
    "Expiration date" : "Utløpsdato",
    "Choose a password for the public link" : "Vel eit passord for den offentlege lenkja",
    "Resharing is not allowed" : "Vidaredeling er ikkje tillate",
    "Share link" : "Del lenkje",
    "Link" : "Lenkje",
    "Password protect" : "Passordvern",
    "Password" : "Passord",
    "Allow editing" : "Tillat endring",
    "Email link to person" : "Send lenkja over e-post",
    "Send" : "Send",
    "Sending ..." : "Sender …",
    "Email sent" : "E-post sendt",
    "Send link via email" : "Send lenkja via e-post",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppa {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "group" : "gruppe",
    "Unshare" : "Udel",
    "can share" : "kan dela",
    "can edit" : "kan endra",
    "create" : "lag",
    "change" : "endra",
    "delete" : "slett",
    "access control" : "tilgangskontroll",
    "Share" : "Del",
    "Warning" : "Åtvaring",
    "invisible" : "usynleg",
    "Delete" : "Slett",
    "Rename" : "Endra namn",
    "The object type is not specified." : "Objekttypen er ikkje spesifisert.",
    "Add" : "Legg til",
    "unknown text" : "ukjend tekst",
    "new" : "ny",
    "Updating to {version}" : "Oppdaterer til {version}",
    "Please reload the page." : "Ver venleg og last sida på nytt.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Oppdateringa feila. Ver venleg og rapporter feilen til <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-fellesskapet</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Oppdateringa er fullført. Sender deg vidare til ownCloud no.",
    "Personal" : "Personleg",
    "Users" : "Brukarar",
    "Apps" : "Program",
    "Admin" : "Admin",
    "Help" : "Hjelp",
    "Access forbidden" : "Tilgang forbudt",
    "File not found" : "Fann ikkje fila",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappa og filene dine er sannsynlegvis tilgjengelege frå Internett sidan .htaccess-fila ikkje fungerer.",
    "Create an <strong>admin account</strong>" : "Lag ein <strong>admin-konto</strong>",
    "Username" : "Brukarnamn",
    "Data folder" : "Datamappe",
    "Configure the database" : "Set opp databasen",
    "Database user" : "Databasebrukar",
    "Database password" : "Databasepassord",
    "Database name" : "Databasenamn",
    "Database tablespace" : "Tabellnamnrom for database",
    "Database host" : "Databasetenar",
    "Finish setup" : "Fullfør oppsettet",
    "Log out" : "Logg ut",
    "Search" : "Søk",
    "Log in" : "Logg inn",
    "Alternative Logins" : "Alternative innloggingar",
    "Use the following link to reset your password: {link}" : "Klikk følgjande lenkje til å nullstilla passordet ditt: {link}",
    "New password" : "Nytt passord",
    "Reset password" : "Nullstill passord"
},
"nplurals=2; plural=(n != 1);");
